/*******************************************************************************
* File Name: Pin_Switch.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Pin_Switch.h"


/*******************************************************************************
* Function Name: Pin_Switch_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Pin_Switch_Write(uint8 value) 
{
    uint8 staticBits = (Pin_Switch_DR & (uint8)(~Pin_Switch_MASK));
    Pin_Switch_DR = staticBits | ((uint8)(value << Pin_Switch_SHIFT) & Pin_Switch_MASK);
}


/*******************************************************************************
* Function Name: Pin_Switch_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Pin_Switch_DM_STRONG     Strong Drive 
*  Pin_Switch_DM_OD_HI      Open Drain, Drives High 
*  Pin_Switch_DM_OD_LO      Open Drain, Drives Low 
*  Pin_Switch_DM_RES_UP     Resistive Pull Up 
*  Pin_Switch_DM_RES_DWN    Resistive Pull Down 
*  Pin_Switch_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Pin_Switch_DM_DIG_HIZ    High Impedance Digital 
*  Pin_Switch_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Pin_Switch_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Pin_Switch_0, mode);
}


/*******************************************************************************
* Function Name: Pin_Switch_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Pin_Switch_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Pin_Switch_Read(void) 
{
    return (Pin_Switch_PS & Pin_Switch_MASK) >> Pin_Switch_SHIFT;
}


/*******************************************************************************
* Function Name: Pin_Switch_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Pin_Switch_ReadDataReg(void) 
{
    return (Pin_Switch_DR & Pin_Switch_MASK) >> Pin_Switch_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Pin_Switch_INTSTAT) 

    /*******************************************************************************
    * Function Name: Pin_Switch_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Pin_Switch_ClearInterrupt(void) 
    {
        return (Pin_Switch_INTSTAT & Pin_Switch_MASK) >> Pin_Switch_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
